==> dde-shell_1.99.32.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_bn.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bn">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="159"/>
        <source>Indicator Style</source>
        <translation>অনুক্রমণিকা স্টাইল</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="161"/>
        <source>Fashion Mode</source>
        <translation>ফ্যাশন মোড</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="166"/>
        <source>Efficient Mode</source>
        <translation>এফিকিএন্ট মোড</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="203"/>
        <source>Left</source>
        <translation>বাম</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="191"/>
        <source>Position</source>
        <translation>অবস্থান</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="172"/>
        <source>Mode</source>
        <translation>মোড</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="176"/>
        <source>Align Left</source>
        <translation>বামে সাজানো</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="178"/>
        <source>Align Top</source>
        <translation>শীর্ষে সাজানো</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="185"/>
        <source>Align Center</source>
        <translation>মাধ্যমে সাজানো</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="193"/>
        <source>Top</source>
        <translation>শীর্ষ</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="198"/>
        <source>Bottom</source>
        <translation>নিচে</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="208"/>
        <source>Right</source>
        <translation>ডান</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="214"/>
        <source>Status</source>
        <translation>অবস্থান</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="216"/>
        <source>Keep Shown</source>
        <translation>প্রদর্শিত রাখুন</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="221"/>
        <source>Keep Hidden</source>
        <translation>স্পর্ধিত রাখুন</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="226"/>
        <source>Smart Hide</source>
        <translation>বুদ্ধিমান স্পর্ধিত</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="233"/>
        <source>Dock Settings</source>
        <translation>ডক সেটিংস</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.37.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_bn.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bn">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>অনুক্রমণিকা স্টাইল</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>ফ্যাশন মোড</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>এফিকিএন্ট মোড</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>ক্লาসিক রূপ</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>মাধ্যমিক রূপ</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>বাম</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>অবস্থান</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>মোড</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>শীর্ষ</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>নিচে</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>ডান</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>অবস্থান</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>প্রদর্শিত রাখুন</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>স্পর্ধিত রাখুন</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>বুদ্ধিমান স্পর্ধিত</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>ডক সেটিংস</translation>
    </message>
</context>
</TS>
